# source("/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Table2.R")
## Programme to plot shocks and export to data file. 
## Formerly named:
## "/Users/lawrenceuren/Dropbox/Depression/Final_GD/govshocksnew.R"
## Also, examine properties of the data. 
## Clear previous information.

rm(list=ls(all=TRUE))

## Load HPfilter - 
source("/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/hpfilter.R")

## Load Monash graphs
source("/Users/lawrenceuren/Documents/Research/Miscellaneous/Computing/R/monash/R/setps.R")

x1 = read.table("/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/worldgy.csv", sep=",", header=TRUE) 
# Data constructed from various sources. See readme.txt. Years: 1920-1939
# V1, foreign govt spending.
# V2, world output. 
gstarhp = hpfilter(log(x1$V1), 100) # hpfilter world govt spending.
ystarhp = hpfilter(log(x1$V2), 100) # hpfilter world output. 

x2= read.table("/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Butlin_datar.csv", sep=",", header=TRUE)
# Data from Butlin (1977) database

iyear = 1 # year
igdp = 2 # gdp real
iprice = 3;# price level 
iemp = 4; # employment
ihoursm = 5; # hours male
ihoursf = 6; # hours female 
im1 = 7; # m1
im2 = 8; # m2
iy = 9; # real gdp
igc_r = 10; # gov consumption (real)
iipd_r = 11; # investment, private dewellings (r)
iipk_r = 12; # investment, private nondwellings (r) 
iigd_r = 13; # investment, gov, dwellings (r)
iigk_r = 14; # investment, gov, capital stock (r) 
imp_r = 15; # imports (r)
ixp_r = 16; # exports (r)
ipop = 17; # population

y_hp = hpfilter(log(x2$realgdp), 100) # Filtered output. 
p_hp = hpfilter(log(x2$price), 100) # Filtered price
nx_gdp = (x2$xport_r - x2$mport_r)/x2$realgdp # Scaled, relative to gdp

# Domestic govt spending
g_domestic = x2$gc_r + x2$gid_r + x2$gind_r
g = hpfilter(log(g_domestic), 100)

# Domestic technology
w = 0.75 # weight on male employment
hours = x2$emp*(w*x2$hoursm + (1-w)*x2$hoursf)
a1 = x2$realgdp/hours; # tech based upon output-employment observations
a1f = hpfilter(log(a1), 100) # HPfilter

gshare = g_domestic/x2$gdp
g_acf = acf(g$cyc) # autocorrelation domgovt spending
gstar_acf = acf(gstarhp$cyc) # autocorrelation foreign govt spending

# World prices - weight on cpi by country
x3 = read.table("/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/worldprices.csv", sep=",", header=TRUE)
worldp = x3$france/x3$france[10]*100*0.15+x3$uk*0.2+x3$usa*0.65; # world price. 
worldphp = hpfilter(log(worldp), 100)
w_acf = acf(worldphp$cyc)

x5 = read.table("/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/tot.csv", sep=",", header=TRUE)

tot_hp = hpfilter(log(x5$tot), 100) # Filtered terms of trade. 

# exchange rate data. 
exdata = read.table('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/exchangedata.csv', sep=",");
e1 = log(exdata$V1/exdata$V1[25]) # Sterling.

t0 = 1925
t1 = 1938
tstart = 1920

j= t0-tstart+1
k = t1-tstart+1

# Export shocks for simulation files.
# Tech, foreign output, domestic govt, foreign govt, world prices, exchange rates. 1920-1939. 
shocks = matrix(c(a1f$cyc[20:39], ystarhp$cyc, g$cyc[20:39], gstarhp$cyc, worldphp$cyc, e1[20:39]), nrow=20, ncol=6, byrow=FALSE)

write.table(shocks, "/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/govshocks.txt", row.names=FALSE, col.names=FALSE, sep=",")

# output, terms of trade, net exports to gdp, prices, govt spending, for govt, for output, tech, world prices
data_obs = matrix(c(y_hp$cyc[25:38], tot_hp$cyc[25:38], nx_gdp[25:38], p_hp$cyc[25:38], g$cyc[25:38], gstarhp$cyc[6:19], ystarhp$cyc[6:19], a1f$cyc[25:38], worldphp$cyc[6:19]), nrow = 14, ncol = 9, byrow = FALSE)

write.table(data_obs, "/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/dataobs.csv", row.names=FALSE, col.names=FALSE, sep=",")

# output, tot, nx, price, govt domestic, govt international, output international 
data_orig = matrix(c(x2$realgdp[25:38], x5$tot[25:38], x2$price[25:38], g_domestic[25:38], x1$V1[6:19], x1$V2[6:19]), nrow=14, ncol=6)

# standard deviations
sd(data_obs) # Row 1 of Table 2

# autocorrelations
acfy = acf(data_obs[,1])
acftot = acf(data_obs[,2])
acfnx = acf(data_obs[,3])
acfp = acf(data_obs[,4])
acfg = acf(data_obs[,5])
acfgstar = acf(data_obs[,6])
acfystar = acf(data_obs[,7])
acftech = acf(data_obs[,8])
acfpstar = acf(data_obs[,9])
acfvector = c(acfy$acf[2], acftot$acf[2], acfnx$acf[2], acfp$acf[2], acfg$acf[2], acfgstar$acf[2], acfystar$acf[2], acftech$acf[2], acfpstar$acf[2]) # Row 2 of Table 2

cor(data_obs) # Rest of Table 2