% Lawrence Uren
% 7/11/2010. 
% Solve new keynesian open economy model.
% includes government spending with flex exchange rate
% Uses McCallum solvek.m file. 
% Essentially, matrix version of method of undetermined coefficients.

% Setup
% clear; clear variables
% clf;

% A E_t(x_t+1) = B x_t + C z_t
% indices for A-, B-matrix
ix = 1;
ipi = 2;
iir = 3;

% indices for C-matrix
ia = 1; % tech
iystar = 2; % world output
ig = 3; % domestic govt
igstar = 4; % international govt
icon = 5; % constant

A = zeros(3,3);
B = zeros(3,3);
C = zeros(3,5);

% equation 1: x_t = E_t x_t+1 - 1/Sigma_G (r_t - E_t pi_t+1 - rr_t)
% -> E_t x_t+1 + 1/Sigma_G E_t pi_t+1 = x_t + 1/sigma_alpha (r_t - rr_t)
A(1, ix) = 1;
A(1, ipi) = (1-sg)/sigma_beta;

B(1, ix) = 1;
B(1, iir) = (1-sg)/sigma_beta;

% parameters to be entered: 
C(1, ia) = -Tau*(rho_a-1); % technology shock 
C(1, iystar) = -(Theta_ystar + Psi)*(rho_y-1); % foreign output
C(1, igstar) = -(Theta_gstar + Lambda_gstar)*(rho_gstar-1); % foreign govt spending
C(1, ig) = -(Theta_g + Lambda_g)*(rho_g-1); % domestic govt spending
C(1, icon) = -rho*(1-sg)/sigma_beta; % constant

% compare with previous results for model without government spending. 
% C(1, ia) = bigtau*(1-rho_a);
% C(1, iystar) = - alpha*bigtheta*phi*(rho_y-1)/(sigma_alpha+phi); % double check. 
% C(1, icon) = - rho/sigma_alpha;

% equation 2: pi_t = beta E_t pi_t+1 + kappa_alpha x_t
A(2, ipi) = beta;

B(2, ipi) = 1;
B(2, ix) = -kappa_alpha;

% equation 3: ir_t = rr_t + phi_y x_t + phi_pi pi_t
% rr_t = rho - sig...*a_t+alpha*si...(rho_a-1)
B(3, iir) = -1;
B(3, ipi) = phi_pi;
B(3, ix) = phi_y;

C(3, icon) = rho;

D=[rho_a, 0, 0, 0 , 0; 
    0, rho_y, 0, 0, 0; 
    0, 0, rho_g, 0, 0; 
    0, 0, 0, rho_gstar, 0; 
    0, 0  0, 0, 1]; % correlation matrix

nk = 0; % number predetermined. 

% solution:
[m,n,p,q,z22h,s,t,lambda] = solvek(A,B,C,D,nk); % call McCallum procedure.

n % return key object.