% Simulate GM under fixed exchange rate
% Import shocks, solution to model
% Run after gm_gov_sol.m and govshocksnew.R
% Examines fixed exchange rate with devaluations 
% given by Flexible Taylor policy. 

shock = dlmread('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/govshocks.txt');
shock = shock';
er_flex = dlmread('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Flexbase/er.txt');

% Order: tech, ystar, domestic g, foreign g, foreign prices, exchange rates
ia = 1;
iystar = 2;
ig = 3;
igstar = 4;
ipstar = 5;
ie = 6;

% start year: 
t0 = 1925;
t1 = 1938;
j = t0-1919; % starting element
k = t1-1919; % total years
l = t1-t0+1; % number observations. 
m = t0-1900; % Butlin data indices
n = t1-1900; % Butlin data indices

% Replace exchange rate data with exchange rate under flexible policy.
shock(6, j:k) = er_flex;

% Construct domestic price level, t0-t1.
p_h = zeros(l,1);
for i = 1:l-1
     p_h(i+1) = mu1*p_h(i) + gamma*shock(:,i+j); % p_h, 1925-1938. 
end
% The first calculation is 1925. The shock vector goes from 1920-1939.
% The first shock vector i+j which is 1925. 

% terms of trade, output and natural rate
s = shock(ie, j:k)' + shock(ipstar,j:k)' - p_h; % pstar + e - ph
y = shock(iystar, j:k)'+(1-alpha)*sg*(shock(ig,j:k)-shock(igstar,j:k))'+(alpha*omega+(1-alpha)*(1-sg))/sigma*s; % output 
ytn = Tau*shock(ia, j:k)+Psi*shock(iystar, j:k)+Lambda_gstar*shock(igstar, j:k) + Lambda_g*shock(ig, j:k); % natural level of output
p_agg = p_h + alpha*s; % home prices are aggregate of domestic and foreign produced goods. 
nx = alpha*((omega/sigma-1)*s + sg*(shock(igstar, j:k) - shock(ig, j:k))');

%%%%%----------------
% Counterfactual exercise. 

% Decompose into relative importance of shocks. 
p_d = zeros(6, l); % domestic prices. 
s_cf = zeros(6, l); % counterfactual terms of trade
y_cf = zeros(6, l); % counterfactual output. 
g_cf = zeros(6, l); % counterfactual government spending. 

for i=1:6 % consider counterfactual exercises
    id = zeros(6);
    id(i,i) = 1;
    shock_cf = id*shock; % set other shocks other than i to zero.
        for t=1:l-1
             p_d(i,t+1) = mu1*p_d(i,t) + gamma*shock_cf(:,j+t);
        end
    s_cf(i,:) = shock_cf(ie,j:k) + shock_cf(ipstar, j:k) - p_d(i,:);
    y_cf(i,:) = shock_cf(iystar,j:k)+ (1-alpha)*sg*(shock_cf(ig,j:k)-shock_cf(igstar,j:k)) + (omega*alpha+(1-alpha)*(1-sg))/sigma*s_cf(i,:);
    g_cf(i, :)=(1-alpha)*sg*(shock_cf(ig,j:k)-shock_cf(igstar,j:k)); % contribution of government to output
end

test = y - sum(y_cf)'; % should be close to zero due to linearity.

% Export some of the results: 
endo_r = [s'; y'; ytn; p_h'; p_agg'];

% dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/endo_r.txt', endo_r);
 
% % Export counterfactual results. 
% dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/p_cf.txt', p_d);
% dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/s_cf.txt', s_cf);
% dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/y_cf.txt', y_cf);

