% Matlab code by Lawrence Uren
% 5 Dec, 2011
% Compare data and model under fixed exchange rates
% Economic Policy During the Depression in a Small Open Economy.  

%% Observed Data:
% Import Terms of Trade data: (Butlin)
tot = csvread('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/tot.csv', 1,0); 
tot_log = log(tot(:,3));
tot_log_f = hpfilter2(tot_log, 100);
tot_log_c = tot_log - tot_log_f; % cyclical component of the terms of trade

% Import Butlin database: 
% data items: year, gdp, price, employment, hoursm, hoursf, 
% m1, m2, real gdp,
% gov con (r), inv pri dwel (r), inv pri nond (r), 
% gov inv dwel (r), gov inv non-d (r), import (r), export (r), pop.

z = csvread('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Butlin_datar.csv',1,0);
ozgdpt = hpfilter2(log(z(:,9)), 100);
ozgdpf = log(z(:,9)) - ozgdpt; % cyclical component of gdp (real)

% Net exports:
netxports = z(:, 16) - z(:, 15); % exports - imports.
nxport_gdp = netxports./z(:,9); % relative to gdp. 

% Prices
p_trend = hpfilter2(log(z(:,3)), 100);
p_cyclical = log(z(:,3)) - p_trend; % cyclical component of prices

inf_cyc = diff(p_cyclical); % inflation, detrended prices
std(inf_cyc(26:38));
acpid = autocorr(inf_cyc(26:38), 1);

%% Comparison with Model Output
% Correlation between model and data
ymd = corr(ozgdpf(25:38), y); % output
nxmd = corr(nxport_gdp(25:38), nx); % net exports
totmd = corr(tot_log_c(25:38), s); % terms of trade
pmd = corr(p_cyclical(25:38), p_agg); % domestic price level aggregating imports and exports.

% Correlation between model and data:
cormodata = [ymd, nxmd, totmd, pmd];

inf_mod = diff(p_agg); % model calculated inflation.
std(inf_mod);

model_data = [y'; s'; nx'; p_agg'; shock(ig, 6:19); shock(igstar, 6:19); shock(iystar, 6:19); shock(ia, 6:19); shock(ipstar, 6:19)]'; 
% order: output, terms of trade, net exports, prices 
% domestic govt, foreign govt, foreign output, domestic
% tech, foreign prices.

sdm = std(model_data);
cormd = corr(model_data);

% Calculate autocorrelations of endogenous variables
acy = autocorr(y', 1);
acnx = autocorr(nx', 1);
actot = autocorr(s', 1);
acp = autocorr(p_agg, 1);
acpim = autocorr(inf_mod, 1);
acg = autocorr(shock(ig, 6:19), 1);
acgstar = autocorr(shock(igstar, 6:19), 1);
actech = autocorr(shock(ia, 6:19), 1);
acpstar = autocorr(shock(ipstar, 6:19), 1);
acystar = autocorr(shock(iystar, 6:19), 1);
% Collect autocorrelations of endogenous variables
acvector = [acy(2), actot(2), acnx(2), acp(2), acpim(2)];