% Solve fixed exchange rate regime.
% 5 Dec, 2011
% Gali-Monacelli.
% Model with government spending.
% See Mathematica code - fe_gm_gov.nb for solution.

% Analytically, describes fixed e equilibrium.
% A p_H,t = p_H,t-1 + \beta E_t p_H,t+1 + C y_t^* + D p_t^* + E a_t
% Solution:
% p_H,t = mu_1 p_H,t-1 + gamma1 y_t^* + gamma2 g_t^* + gamma3 g_t + gamma4
% * a_t + gamma5 p_t^* + gamma6 e_t

% Solution outlined in fixed_exchange.pdf or payne_uren_v2.pdf

lambda = (1-beta*theta)*(1-theta)/theta;

Sigma1 = (sigma-sigma_beta)/(1-sg);
Sigma2 = -sg*((sigma-sigma_beta*(1-alpha))/(1-sg));
Sigma3 = sigma_beta/(1-sg) + phi; 
Sigma4 = -sigma*(1-alpha)*sg/(omega*alpha+(1-alpha)*(1-sg));
Sigma5 = -(1+phi);
Sigma6 = (omega*alpha+(1-alpha)*(1-sg))/sigma;

A = 1 + beta + lambda*Sigma3*Sigma6;
Omega_ystar = lambda*(Sigma1+Sigma3);
Omega_gstar = lambda*(Sigma2 - Sigma3*(1-alpha)*sg);
Omega_g = lambda*(Sigma4 + Sigma3*(1-alpha)*sg);
Omega_a = lambda*Sigma5;
Omega_pstar = lambda*Sigma3*Sigma6;
Omega_e = lambda*Sigma3*Sigma6;

% Solution to the model. 

mu1 = (A - sqrt(A^2-4*beta))/(2*beta);
gamma1 = 2*Omega_ystar/(A+sqrt(A^2 - 4*beta)-2*beta*rho_y); % foreign output
gamma2 = 2*Omega_gstar/(A+sqrt(A^2 - 4*beta)-2*beta*rho_gstar); % foreign govt
gamma3 = 2*Omega_g/(A+sqrt(A^2 - 4*beta)-2*beta*rho_g); % domestic govt
gamma4 = 2*Omega_a/(A+sqrt(A^2 - 4*beta)-2*beta*rho_a); % tech
gamma5 = 2*Omega_pstar/(A+sqrt(A^2 - 4*beta)-2*beta*rho_pstar); % foreign prices
gamma6 = 2*Omega_e/(A+sqrt(A^2 - 4*beta)-2*beta*rho_e); % exchange rates


gamma = [gamma4, gamma1, gamma3, gamma2, gamma5, gamma6]; 
% Order: tech, ystar, domestic g, foreign g, foreign prices, exchange rates
% to match shock vector from govshocknew.R

