% Matlab code written by Lawrence Uren
% 14/1/2011
% Impulse response function for Gali-Monacelli 
% model with government spending shocks 
% flexible exchange rate.

% Setup
clear; % clear variables
% clf;  clear figures

% Results for small role for government. 
n1 = dlmread('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/sol_nk_gov.txt');
% Solution to GM model.
% From gali_monacelli_gov.m code.  

% order endogenous variables: x (output gap), pi (inflation rate), irate (deviation interest
% rate)
ix = 1;
ipi = 2;
iir = 3;

% order exogenous variables. 
ia = 1; % tech
iystar = 2; % world output
ig = 3; % domestic govt
igstar = 4; % international govt
icon = 5; % constant

run parameters_gmg2

n = 12; % length of impulse response

% Set up loop to run impulse responses. 
rho = [rho_a, rho_y, rho_g, rho_gstar];

x_out = zeros(4, n);
pi_out = zeros(4, n);
r_out = zeros(4, n);
yn_out = zeros(4, n);

% calculate impulse responses.
% loop order corresponds to order exogen. variables

for i=1:4
    shock = zeros(5, n);
    shock(5, :) = ones(1, n);
    shock(i, :) = rho(i).^(0:(n-1));
    output = n1*shock;
    x_out(i, :) = output(ix, :); % output gap
    pi_out(i, :) = output(ipi, :); % inflation
    r_out(i, :) = output(iir, :); % nominal interest rate
    yn_out(i, :) = Tau*shock(1, :) + Psi*shock(2, :) + Lambda_g*shock(3, :) + Lambda_gstar*shock(4, :);
end


dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/yout_flex', x_out);
dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/yn_flex', yn_out);

% diary filename.out.
% uncomment and introduce filename if diary is desired.