% Impulse response fixed exchange rate regime
% First version: 20 November, 2010
% Gali-Monacelli
% Model with government spending.
% Simulate impulse response functions with shocks.

clear all
close all
% First, set up model.

run parameters_gmg2
% Analytically, describes fixed e equilibrium.
% A p_H,t = p_H,t-1 + \beta E_t p_H,t+1 + C y_t^* + D p_t^* + E a_t
% Solution:
% p_H,t = mu_1 p_H,t-1 + gamma1 y_t^* + gamma2 g_t^* + gamma3 g_t + gamma4
% * a_t + gamma5 p_t^* + gamma6 e_t

lambda = (1-beta*theta)*(1-theta)/theta;

% New solution:
Sigma1 = (sigma-sigma_beta)/(1-sg);
Sigma2 = -sg*((sigma-sigma_beta*(1-alpha))/(1-sg));
Sigma3 = sigma_beta/(1-sg) + phi; 
Sigma4 = -sigma*(1-alpha)*sg/(omega*alpha+(1-alpha)*(1-sg));
Sigma5 = -(1+phi);
Sigma6 = (omega*alpha+(1-alpha)*(1-sg))/sigma;

A = 1 + beta + lambda*Sigma3*Sigma6;
Omega_ystar = lambda*(Sigma1+Sigma3);
Omega_gstar = lambda*(Sigma2-Sigma3*(1-alpha)*sg);
Omega_g = lambda*(Sigma4 + Sigma3*(1-alpha)*sg);
Omega_a = lambda*Sigma5;
Omega_pstar = lambda*Sigma3*Sigma6;
Omega_e = lambda*Sigma3*Sigma6;

% Solution to SODE.
% Stochastic process 

mu1 = (A - sqrt(A^2-4*beta))/(2*beta);
gamma1 = 2*Omega_ystar/(A+sqrt(A^2 - 4*beta)-2*beta*rho_y);
gamma2 = 2*Omega_gstar/(A+sqrt(A^2 - 4*beta)-2*beta*rho_gstar);
gamma3 = 2*Omega_g/(A+sqrt(A^2 - 4*beta)-2*beta*rho_g);
gamma4 = 2*Omega_a/(A+sqrt(A^2 - 4*beta)-2*beta*rho_a);
gamma5 = 2*Omega_pstar/(A+sqrt(A^2 - 4*beta)-2*beta*rho_pstar);
gamma6 = 2*Omega_e/(A+sqrt(A^2 - 4*beta)-2*beta*rho_e);

gamma =[gamma1, gamma2, gamma3, gamma4, gamma5, gamma6];
% order, ystar, gstar, g, a, pstar, e

iystar = 1;
igstar = 2;
ig = 3;
ia = 4; 
ipstar =5;
ie = 6;

rho = [rho_y,  rho_gstar, rho_g, rho_a, rho_pstar, rho_e];

n = 12; % length of simulation 

x_out = zeros(5, n);
ph_out = zeros(5, n);
s_out = zeros(5, n);
y_out = zeros(5, n);
pd = zeros(1, n);

% Simulate shocks under a fixed exchange rate regime. 
for i = 1:6
    ph = zeros(1, n+1);
    shock = zeros(6, n); % reset shock to zero
    shock(i, :) = rho(i).^(0:(n-1)); % shock that decays over time
%    shock(i, :) = [1, zeros(1, n-1)]; % instantaneous shock. temporary. 
    for j = 1:n
        ph(j+1) = mu1*ph(j) + gamma*shock(:,j);
    end
    pd = ph(2:n+1);
    s = shock(ie,:)' + shock(ipstar, :)' - pd'; % pstar + e - ph
    y = shock(iystar, :)'+(1-alpha)*sg*(shock(ig, :)-shock(igstar, :))'+(alpha*omega+(1-alpha)*(1-sg))/sigma*s; % output 
    ph_out(i, :) = pd;
    s_out(i, :) = s';
    y_out(i, :) = y';
end

% Loop over plots. 
% for i = 1:6
%     figure(i) 
%     plot(1:n, ph_out(i, :), 1:n, s_out(i,:), 1:n, y_out(i, :))
%     legend('price', 'terms of trade', 'output')
% end

dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/yout_fixed_ng', y_out);