%% Matlab file to conduct simulation of fixed exchange rate. 
% Select appropriate case to simulate. 

switch 'baseline' % select appropriate model to run. 
    
    case 'baseline'
        
        clear
        
        run parameters_gmg2 % import parameters
        
        run gm_gov_sol % model solution
        
        run gm_baseline_sim % simulate model with shocks
        
        % Export results
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Baseline/endo_r.txt', endo_r);
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Baseline/y_cf.txt', y_cf);
        
        run gm_fixed_compare
        
        % model order: output, net exports, terms of trade, prices.
        % Statistics used for Table 3.
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Baseline/sdm.txt', sdm); % standard deviation
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Baseline/cormd.txt', cormd); % correlation matrix
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Baseline/cf.txt', y_cf); % counterfactual output
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Baseline/cormodata.txt', cormodata); % correlation with data
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Baseline/acvector.txt', acvector); % autocorrelations
 
   
    case 'erdecompose' % file to examine effect of exchange rate movements.
        
        clear 
        
        run parameters_gmg2
        
        run gm_gov_sol
        
        run gm_alternate_sim
        
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Alternate/endo_r.txt', endo_r);
        
        run gm_fixed_compare
        
        
    case 'mid_eta' % Code for appendix.
        
        clear
        
        run parameters_gmg_eta3 % import parameters. eta = 3. 
        
        run gm_gov_sol % model solution
        
        run gm_baseline_sim % simulate model with shocks
        
        % Export results
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/mid_eta/endo_r.txt', endo_r);
        
        run gm_fixed_compare
        
        % model order: output, net exports, terms of trade, prices.
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/mid_eta/sdm.txt', sdm);
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/mid_eta/cormd.txt', cormd);
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/mid_eta/cormodata.txt', cormodata);
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/mid_eta/acvector.txt', acvector); 
    
    case 'high_eta' % for online appendix
        
        clear 
        
        run parameters_gmg_eta6 % import parameters. eta = 6. 
        
        run gm_gov_sol % model solution
        
        run gm_baseline_sim % simulate model with shocks

        % Export model results
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/high_eta/endo_r.txt', endo_r);
        
        run gm_fixed_compare
        
        % model order: output, net exports, terms of trade, prices.
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/high_eta/sdm.txt', sdm);
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/high_eta/cormd.txt', cormd);
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/high_eta/cormodata.txt', cormodata);
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/high_eta/acvector.txt', acvector); 
 
    
    case 'thetal'
        
        clear 
        
        run parameters_thetal % import parameters
        
        run gm_gov_sol % model solution
        
        run gm_baseline_sim % simulate model with shocks
        
        % Export results
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Thetal/endo_r.txt', endo_r);
        
        run gm_fixed_compare
        
        % model order: output, net exports, terms of trade, prices.
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Thetal/sdm.txt', sdm); % standard deviation
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Thetal/cormd.txt', cormd); % correlation matrix
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Thetal/cf.txt', y_cf); % counterfactual output
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Thetal/cormodata.txt', cormodata); % correlation with data
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/Thetal/acvector.txt', acvector); % autocorrelations
    
    
    case 'thetah' % for online appendix
        
        clear 
        
        run parameters_thetah % import parameters
        
        run gm_gov_sol % model solution
        
        run gm_baseline_sim % simulate model with shocks
        
        % Export results
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Thetah/endo_r.txt', endo_r);
        
        run gm_fixed_compare
        
        % model order: output, net exports, terms of trade, prices.
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Thetah/sdm.txt', sdm); % standard deviation
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Thetah/cormd.txt', cormd); % correlation matrix
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Thetah/cf.txt', y_cf); % counterfactual output
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Thetah/cormodata.txt', cormodata); % correlation with data
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Thetah/acvector.txt', acvector); % autocorrelations
      

    case 'gammah' % for online appendix
        
        clear 
        
        run parameters_gammah % import parameters
        
        run gm_gov_sol % model solution
        
        run gm_baseline_sim % simulate model with shocks
        
        % Export results
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Gammah/endo_r.txt', endo_r);
        
        run gm_fixed_compare
        
        % model order: output, net exports, terms of trade, prices.
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Gammah/sdm.txt', sdm); % standard deviation
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Gammah/cormd.txt', cormd); % correlation matrix
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Gammah/cf.txt', y_cf); % counterfactual output
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Gammah/cormodata.txt', cormodata); % correlation with data
        dlmwrite('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Gammah/acvector.txt', acvector); % autocorrelations
     
        
        
    case 'zerog' % model with zero change to govt spending over the Depression period
        
        clear 
        
        run parameters_gmg2
        
        run gm_gov_sol
        
        run gm_zerog
        
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/zerog/endo_r.txt', endo_r);
        

    case 'largeg' % model with sg = 0.25. 
        
        clear 
        
        run parameters_sgh % input parameters
        
        run gm_gov_sol % solve model - requires McCallum code
        
        run gm_zerog % simulate model with zero govt spending changes
        
        dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/largeg/endo_r.txt', endo_r);

        
    case 'wicksellian' % model with suggested Wicksellian policy.
        
        clear 
        
        run parameters_gmg2 % import parameters
        
        run wicksell% run alternate "Wicksellian policy"
        
        run wicksell_sim
end