% Lawrence Uren
% 1/12/2010
% Simulate economy subject to shocks received in the great depression
% but following modern monetary and fiscal policy.
% to be run following govshocksnew.R and gali_monacelli_gov.m


% Setup
clear; % clear variables

% Load shocks
data = dlmread('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/govshocks.txt');
% tech, world output, domestic govt, foreign govt., p*, e.
% 20 years of data. 1920-1939
pstar = data(:, 5); % Extract p*
edata = data(:, 6); % Extract e
data = data(:, 1:4); % Remove p* and e. 

% Load solution to model: 
n1 = dlmread('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/sol_nk_gov.txt');
% 3x5 matrix. 3 endogenous variables. 5 exogenous shocks. 
% ordering of shocks solution: tech, world output, domestic govt, foreign govt

% create matrix of shocks. world output: weighted average.
% shock = zeros(5, 20);
% shock(5, :) = ones(1, 20);
shock = [data'; ones(1,length(data))];
% 5x20 - 5 exogenous shocks, 20 time periods. 

% aggregate results.
simpath = (n1*shock)';

% order endogenous variables: x (output gap), pi (inflation rate), irate (deviation interest
% rate)
ix = 1;
ipi = 2;
iir = 3;

% order exogenous variables. 
ia = 1; % tech
iystar = 2; % world output
ig = 3; % domestic govt
igstar = 4; % international govt
icon = 5; % constant

dlmwrite('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Output/sim_shocks_gov.txt', simpath);

run parameters_gmg2

t0 = 1925; % start year. 
t1 = 1938; % end year.
j = t0-1919; % starting element.
k = t1-1919; % total years.
l = t1-t0+1; % number observations. 
m = t0-1900; % Butlin data indices.
n = t1-1900; % Butlin data indices.

 % Description of output:
ytn = Tau*shock(ia, j:k)+Psi*shock(iystar, j:k)+Lambda_gstar*shock(igstar, j:k) + Lambda_g*shock(ig, j:k); % natural level of output

% Natural output by shock: (tech., y^*, g^*, g). 
ytn_a = Tau*shock(ia, j:k);
ytn_ystar = Psi*shock(iystar, j:k);
ytn_gstar = Lambda_gstar*shock(igstar, j:k);
ytn_g = Lambda_g*shock(ig, j:k);

output = ytn'+simpath(j:k, ix);

% Natural rate of interest.
% ir_t = rr_t + phi_y x_t + phi_pi pi_t
% rr_t = rho + sigma_beta/(1-sg)*(Tau*(rho_a-1) + (Theta_ystar+ Psi)*(rho_ystar-1)* ystar
% + (Theta_g + Lambda_g)*(rho_g-1)*g +
% (Theta_gstar+Lambda_gstar)*(rho_gstar-1)*g_star)

rtn_a = Tau*(rho_a-1);
rtn_iystar = (Theta_ystar+Psi)*(rho_y-1);
rtn_igstar = (Theta_gstar+Lambda_gstar)*(rho_gstar-1);
rtn_ig = (Theta_g + Lambda_g)*(rho_g-1);

rtn =rho + sigma_beta/(1-sg)* (rtn_a*shock(ia, :)+rtn_iystar*shock(iystar,:)+rtn_igstar*shock(igstar,:)+rtn_ig*shock(ig,:));

% observed output data:
z = csvread('/Users/lawrenceuren/Dropbox/Depression/JMCB_GD/Code/Butlin_datar.csv',1,0);
ozgdpt = hpfilter2(log(z(:,9)), 100);
ozgdpf = log(z(:,9)) - ozgdpt;

% Other variables: 
s = sigma/(alpha*omega+(1-alpha)*(1-sg))*(output'-shock(iystar, j:k) - (1-alpha)*sg*(shock(ig,j:k)-shock(igstar, j:k))); % terms of trade
nx = alpha*((omega/sigma-1)*s+sg*(shock(ig,j:k)-shock(igstar, j:k))); % net exports

% Deviations from natural rate of interest
% Actual less natural rate. 
% Positive values imply contractionary. Negative expansionary. 
dev_ir = simpath(:, iir)' - rtn;

% Government spending couterfactual exercise. 
shock_cf = shock;
shock_cf(ig,:) = zeros(1, length(data)); % set government spend shocks equal to zero. 

simpath_cf =  (n1*shock_cf)';
ytn_cf = Tau*shock_cf(ia, j:k)+Psi*shock_cf(iystar, j:k)+Lambda_gstar*shock_cf(igstar, j:k) + Lambda_g*shock_cf(ig, j:k); % natural level of output
output_cf = ytn_cf'+simpath(j:k, ix);


% imported data - fixed exchange rate results.
% fix_output = dlmread('/Users/lawrenceuren/Documents/Research/Projects/OzEcoHist/Depression/Results_GD/Baseline/endo_r.txt'); % % p_h, y
% ypfe = fix_output(2, :);
% 
% % Construct exchange rate under flexible exchange rate economy. 
p_ht = cumsum(simpath(:,ipi)); % domestic prices - m+1:n+1.
er_t = s - pstar(j:k)' + p_ht(j-1:k-1)';

%%%%%%%%%%%---------------
% Use to contain code to construct Figures. 
% These figures now produced by R. 